import { useState } from "react";
import "./index.less";
import Guide from "./components/Guide";
import { useMount } from "../../hook";
import Player from "./components/DPlayer";
import { useParams } from "react-router-dom";
import { getChapterGuideById } from "../../api";
import { ms2Time } from "./util";
import Result from "../../components/Result";
import PlayCircle20Regular from "@ricons/fluent/PlayCircle20Regular";
import BookLetter20Regular from "@ricons/fluent/BookLetter20Regular";
import { Icon } from "@ricons/utils";

function CourseDetail() {
  const { id: course_id = "" } = useParams();
  const [toc, setToc] = useState([]);
  const [view, setView] = useState<any>(null);

  useMount(() => {
    if (!!course_id)
      getChapterGuideById(course_id).then((res) => {
        const { data } = res;
        const processToc = data?.chapterList.map((item: any) => {
          return {
            title: item.chapter_title,
            level: +item.chapter_level,
            time: ms2Time(+item.media_time),
            icon: !!item.media_url ? (
              <Icon size={20}>
                <PlayCircle20Regular />
              </Icon>
            ) : null,
            active: false,
            view: (
              <Player
                video={{ url: item.media_url, pic: item.media_cover_url }}
              />
            ),
          };
        });
        const append = [
          {
            title: "导读",
            level: 1,
            time: "",
          },
          {
            title: "介绍 / 下载",
            level: 2,
            time: "",
            active: true,
            view: <Guide html={data?.guide.guide_html} />,
          },
          ...processToc,
        ];
        setToc(append as any);
        setView(<Guide html={data?.guide.guide_html} />);
      });
  });

  const onclickItem = (i: any) => {
    setToc((t: any) =>
      t.map((p: any) => ({ ...p, active: i.title === p.title }))
    );
    setView(i.view ?? <Result />);
  };

  return (
    <div className="course-detail">
      <aside className="table-of-content">
        <h2>云顶计划：K线</h2>
        <div>
          <div style={{ color: "var(--color-text-3)" }}>
            <span>2023年3月2日</span>
          </div>
        </div>
        <div className="toc">
          {toc.map((i: any) => {
            if (i.level === 1) {
              return (
                <div className="level-1" key={i.title}>
                  {i.title}
                </div>
              );
            } else if (i.level === 2) {
              return (
                <div
                  className={`level-2 ${i.active ? "active" : ""}`}
                  key={i.title}
                  onClick={() => onclickItem(i)}
                >
                  <div className="bs ellipsis fc">
                    {i.icon}
                    <span>{i.title}</span>
                  </div>
                  <span className="time">{i.time}</span>
                </div>
              );
            }
          })}
        </div>
      </aside>
      <div className="content">{view}</div>
    </div>
  );
}

export default CourseDetail;
